==> Botan-1.1.3.tgz: Botan-1.1.3/include/pkcs8.h <==
/*************************************************
* PKCS #8 Header File                            *
* (C) 1999-2002 The Botan Project                *
*************************************************/

#ifndef BOTAN_PKCS8_H__
#define BOTAN_PKCS8_H__

#include <botan/x509.h>

namespace Botan {

/*************************************************
* PKCS #8 Private Key                            *
*************************************************/
class PKCS8_PrivateKey : public virtual X509_PublicKey
   {
   public:
      virtual SecureVector<byte> DER_encode_priv() const = 0;
      virtual void BER_decode_priv(DataSource&) = 0;
      virtual ~PKCS8_PrivateKey() {}
   };

namespace PKCS8 {

/*************************************************
* PKCS #8 Encoding and Decoding Functions        *
*************************************************/
void encode(const PKCS8_PrivateKey&, Pipe&, X509_Encoding = PEM);
void decode(PKCS8_PrivateKey&, DataSource&, X509_Encoding = PEM);
std::string PEM_encode(const PKCS8_PrivateKey&);

void encrypt_key(const PKCS8_PrivateKey&, Pipe&, const std::string&,
                 const std::string& = "PBE-PKCS5v15(MD5,DES/CBC)",
                 X509_Encoding = PEM);
void decrypt_key(PKCS8_PrivateKey&, DataSource&, const std::string&,
                 X509_Encoding = PEM);
std::string PEM_encode(const PKCS8_PrivateKey&, const std::string&);

PKCS8_PrivateKey* load_key(DataSource&, const std::string& = "",
                           X509_Encoding = PEM);

}

}

#endif

==> Botan-1.1.5.tgz: Botan-1.1.5/include/pkcs8.h <==
/*************************************************
* PKCS #8 Header File                            *
* (C) 1999-2002 The Botan Project                *
*************************************************/

#ifndef BOTAN_PKCS8_H__
#define BOTAN_PKCS8_H__

#include <botan/x509.h>

namespace Botan {

/*************************************************
* PKCS #8 Private Key                            *
*************************************************/
class PKCS8_PrivateKey : public virtual X509_PublicKey
   {
   public:
      virtual SecureVector<byte> DER_encode_priv() const = 0;
      virtual void BER_decode_priv(DataSource&) = 0;
      virtual ~PKCS8_PrivateKey() {}
   };

namespace PKCS8 {

/*************************************************
* PKCS #8 Encoding and Decoding Functions        *
*************************************************/
void encode(const PKCS8_PrivateKey&, Pipe&, X509_Encoding = PEM);
void decode(PKCS8_PrivateKey&, DataSource&, X509_Encoding = PEM);
std::string PEM_encode(const PKCS8_PrivateKey&);

void encrypt_key(const PKCS8_PrivateKey&, Pipe&, const std::string&,
                 const std::string& = "PBE-PKCS5v20(SHA-1,TripleDES/CBC)",
                 X509_Encoding = PEM);
void decrypt_key(PKCS8_PrivateKey&, DataSource&, const std::string&,
                 X509_Encoding = PEM);
std::string PEM_encode(const PKCS8_PrivateKey&, const std::string&);

PKCS8_PrivateKey* load_key(DataSource&, const std::string& = "",
                           X509_Encoding = PEM);

}

}

#endif
